{****************************************************************************************

"AutoNumberTopicCaption" HelpNDoc script. Copyright (c) IBE Software
--------------------------------------------------------------------
Update every topics' captions to prepend its hierarchy number.
For example topic named "Welcome" with the hierarchy "2.5.4" will be captioned
"2.5.4 Welcome" once the script is run.
It is recommended to use templates instead to number topic titles in generated documents.
Actions from this script are no undoable.

Customization:
--------------
* SEPARATOR => the separator to use in the numbering process. E.g. '-' => '2-5-4'

****************************************************************************************}

const
  // Separator used in the numbering process
  SEPARATOR = '.';

// Converts an array of Integer to a valid hierarchy string. E.g. [2,5,4] => '2.5.4'
function HierarchyToString(const aHierarchy: array of Integer): string;
var
  nItem: Integer;
begin
  Result := '';
  for nItem := 0 to High(aHierarchy) do
  begin
    if nItem > 0 then Result := Result + SEPARATOR;
    Result := Result + IntToStr(aHierarchy[nItem]);
  end;
end;

var
  aTopicId: string;
  aTopicCaption: string;
begin
  // Get the first topic of the project
  aTopicId := HndTopics.GetTopicFirst();
  // Go through each topic
  while aTopicId <> '' do
  begin
    // Get current topic's caption
    aTopicCaption := HndTopics.GetTopicCaption(aTopicId);
    // Update the caption
    aTopicCaption := Format('%s. %s', [HierarchyToString(HndTopicsEx.GetTopicIndexHierarchyGenerated(aTopicId, False, False)), aTopicCaption]);
    // Set new caption
    HndTopics.SetTopicCaption(aTopicId, aTopicCaption);
    // Next topic
    aTopicId := HndTopics.GetTopicNext(aTopicId);
  end;
end.