{****************************************************************************************

"ResetHelpContextNumbers" HelpNDoc script. Copyright (c) IBE Software
---------------------------------------------------------------------
See: https://www.helpndoc.com/articles/2017-08-17-using-helpndoc-scripting-capabilities-automatically-reset-all-help-context
Context numbers can become messy as HelpNDoc project evolves. This script will reset
each topic's context number so that they are setup incrementally from first topic till
last one.

****************************************************************************************}

const
  // Temporary context number used. MaxInt is the maximum possible number.
  TEMP_MAX = MaxInt div 2;

  // Update context number for all topics starting with "StartingAtNb"
  procedure UpdateContextNumbers(const StartingAtNb: Integer);
  var
    aTopicId: string;
    aCurrentNb: Integer;
  begin
    // Init
    aCurrentNb := StartingAtNb;
    // Get first topic
    aTopicId := HndTopics.GetTopicFirst();
    // Iterate over topics
    while aTopicId <> '' do
    begin
      // Set the context number for the current topic
      HndTopics.SetTopicHelpContext(aTopicId, aCurrentNb);
      // Set next number
      Inc(aCurrentNb);
      // Move to next topic
      aTopicId := HndTopics.GetTopicNext(aTopicId);
    end;
  end;

begin
  // Make sure all topics have unique large context numbers
  UpdateContextNumbers(TEMP_MAX);
  // Update all topics with context numbers starting at 0
  UpdateContextNumbers(0);
end.