{****************************************************************************************

"SortAllTopics" HelpNDoc script. Copyright (c) IBE Software
-----------------------------------------------------------
Sorts all topics in the table of contents of the currently opened project
alphabetically. Sorting is case insensitive. E.g. the following table of contents:
- Z
- y
  - B
  - a
-X

Will become:
- X
- y
  - a
  - B
- Z

****************************************************************************************}

type
  TStringArray = array of string;
  
  procedure QuickSort(var AArray: TStringArray; ALo, AHi: Integer) ;
  var
    Lo, Hi: Integer;
	Pivot, aTopic: String;
  begin
    Lo := ALo;
    Hi := AHi;
    Pivot := LowerCase(HndTopics.GetTopicCaption(AArray[(Lo + Hi) div 2]));
    repeat
      while LowerCase(HndTopics.GetTopicCaption(AArray[Lo])) < Pivot do 
	   Inc(Lo) ;
      while LowerCase(HndTopics.GetTopicCaption(AArray[Hi])) > Pivot do 
	   Dec(Hi) ;
      if Lo <= Hi then
      begin
        aTopic := HndTopics.GetTopicNextSibbling(AArray[Hi]);
        HndTopics.MoveTopic(AArray[Hi], AArray[Lo], htamInsert);
        if aTopic <> '' then
         HndTopics.MoveTopic(AArray[Lo], aTopic, htamInsert)
		else
		 HndTopics.MoveTopic(AArray[Lo], AArray[Lo], htamAdd);
        aTopic := AArray[Lo];
        AArray[Lo] := AArray[Hi];
        AArray[Hi] := aTopic;
        Inc(Lo);
        Dec(Hi);
      end;
    until Lo > Hi;
    if Hi > ALo then 
	  QuickSort(AArray, ALo, Hi);
    if Lo < AHi then 
	  QuickSort(AArray, Lo, AHi) ;
  end;
  
  procedure SortArray(var AArray: TStringArray);
  begin
    QuickSort(AArray, 0, Length(AArray) - 1);
  end;
  
  procedure FillArray(aTopicId: String);
  var
    List: THndTopicsInfoArray;
    IDArray: TStringArray;
    J: Integer;
  begin
    List := HndTopics.GetTopicDirectChildrenList(aTopicId);
    if Length(List) = 0 then
     Exit;
    SetLength(IDArray, Length(List));
    for J := 0 to Length(List) - 1 do
     IDArray[J] := List[J].Id;
    SortArray(IDArray);
    for J := 0 to Length(IDArray) - 1 do
     FillArray(IDArray[J]);
  end;  
  
var
  aTopicList: TStringArray;
  sTopicId: String;
  nCnt: Integer;
  
begin

  sTopicId := HndTopics.GetTopicFirst;
  SetLength(aTopicList, 0);
  While (sTopicId <> '') do  
  begin
    SetLength(aTopicList, Length(aTopicList) + 1);
    aTopicList[Length(aTopicList) - 1] := sTopicId;
    sTopicId := HndTopics.GetTopicNextSibbling(sTopicId);
  end;
  
  SortArray(aTopicList);
  
  for nCnt := 0 to Length(aTopicList) - 1 do
   FillArray(aTopicList[nCnt]);
   
end.